m128d

Struct m128d 

pub struct m128d(/* private fields */);
🔬This is a nightly-only experimental API. (stdarch_loongarch #117427)
Available on LoongArch64 only.
128-bit wide set of two f64 values, LoongArch-specific

This type is the same as the __m128d type defined in lsxintrin.h, representing a 128-bit SIMD register which internally consists of two packed f64 instances. Usage of this type typically occurs in conjunction with the lsx and higher target features for LoongArch.

Note that unlike m128i, the integer version of the 128-bit registers, this m128d type has one interpretation. Each instance of m128d always corresponds to f64x2, or two f64 values packed together.

The in-memory representation of this type is the same as the one of an equivalent array (i.e. the in-memory order of elements is the same, and there is no padding); however, the alignment is different and equal to the size of the type. Note that the ABI for function calls may not be the same.

Most intrinsics using m128d are prefixed with lsx_ and are suffixed with “d”. Not to be confused with “d” which is used for m128i.