m256i

Struct m256i 

pub struct m256i(/* private fields */);
🔬This is a nightly-only experimental API. (stdarch_loongarch #117427)
Available on LoongArch64 only.
256-bit wide integer vector type, LoongArch-specific

This type is the same as the __m256i type defined in lasxintrin.h, representing a 256-bit SIMD register. Usage of this type typically occurs in conjunction with the lasx target features for LoongArch.

Internally this type may be viewed as:

  • i8x32 - thirty two i8 values packed together
  • i16x16 - sixteen i16 values packed together
  • i32x8 - eight i32 values packed together
  • i64x4 - four i64 values packed together

(as well as unsigned versions). Each intrinsic may interpret the internal bits differently, check the documentation of the intrinsic to see how it’s being used.

The in-memory representation of this type is the same as the one of an equivalent array (i.e. the in-memory order of elements is the same, and there is no padding); however, the alignment is different and equal to the size of the type. Note that the ABI for function calls may not be the same.

Note that this means that an instance of m256i typically just means a “bag of bits” which is left up to interpretation at the point of use.

Most intrinsics using m256i are prefixed with lasx_ and the integer types tend to correspond to suffixes like “b”, “h”, “w” or “d”.